API Documentation
=================

Top-level functions
-------------------

.. automodule:: xlwings
    :members: view

Apps
----

.. autoclass:: xlwings.main.Apps
    :members:

App
---

.. autoclass:: App
    :members:

Books
-----

.. autoclass:: xlwings.main.Books
    :members:

Book
----

.. autoclass:: Book
    :members:

Sheets
------

.. autoclass:: xlwings.main.Sheets
    :members:

Sheet
-----

.. autoclass:: Sheet
    :members:

Range
-----

.. autoclass:: Range
    :members:


Shapes
------

.. autoclass:: xlwings.main.Shapes
    :members:
    :inherited-members:

Shape
-----

.. autoclass:: Shape
    :members:

Charts
------

.. autoclass:: xlwings.main.Charts
    :members:
    :inherited-members:

Chart
-----

.. autoclass:: Chart
    :members:

Pictures
--------

.. autoclass:: xlwings.main.Pictures
    :members:
    :inherited-members:

Picture
-------

.. autoclass:: Picture
    :members:

Names
-----

.. autoclass:: xlwings.main.Names
    :members:

Name
----

.. autoclass:: Name
    :members: